summaryrefslogtreecommitdiffstats
path: root/src/include/usr/ipmi/ipmi_reasoncodes.H
diff options
context:
space:
mode:
authorDonald Washburn <dwashbur@us.ibm.com>2017-06-14 13:08:22 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-06-27 13:21:34 -0400
commit31d097409bd233008676e4779c9e6a7582e8156f (patch)
treeca1c9afa82e0a5aa987b545f160cdbeb37cc4517 /src/include/usr/ipmi/ipmi_reasoncodes.H
parentd408402dfb499755ed265496498fabb5b0400ff0 (diff)
downloadblackbird-hostboot-31d097409bd233008676e4779c9e6a7582e8156f.tar.gz
blackbird-hostboot-31d097409bd233008676e4779c9e6a7582e8156f.zip
Replaced calls to bmc for sensor type with static information.
The sendErrLogToBMC function was calling to the bmc in order to determine the type of a sensor based upon a sensor number. It was determined that the sensor type can be obtained from the sensor number by data loaded during initialization via the TARGETING namespace. The ipmi call from SenorBase::getSensorType was removed from the sendErrLogToBMC function and replaced with a call to IpmiConfigLookup::getSensorType. The getSensorType function from the new IpmiConfigLookup class retrieves sensor data from target attributes and as such does not call the bmc for the type information. * Added the new IpmiConfigLookup class in the IPMI namespace. This class provides static methods to retrive sensor data provided by the IPMI_SENSOR target attribute. In addition to sensor type, the sensor entity id and sensor name can be obtined from this class based upon a sensor number. * Changed sendErrLogToBMC to call IpmiConfigLookup::getSensorType instead of Sensor::SensorBase::getSensorInfo. RTC: 164493 Change-Id: Ie8e7fa5c37fa972d6cecd1e4b69e2d0cb7504533 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/42128 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Prachi Gupta <pragupta@us.ibm.com> Reviewed-by: ILYA SMIRNOV <ismirno@us.ibm.com> Reviewed-by: Richard J. Knight <rjknight@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/include/usr/ipmi/ipmi_reasoncodes.H')
-rw-r--r--src/include/usr/ipmi/ipmi_reasoncodes.H18
1 files changed, 11 insertions, 7 deletions
diff --git a/src/include/usr/ipmi/ipmi_reasoncodes.H b/src/include/usr/ipmi/ipmi_reasoncodes.H
index f4f08cf65..c8931bdb0 100644
--- a/src/include/usr/ipmi/ipmi_reasoncodes.H
+++ b/src/include/usr/ipmi/ipmi_reasoncodes.H
@@ -32,13 +32,16 @@ namespace IPMI
{
enum IPMIModuleId
{
- MOD_IPMISRV_SEND = 0x01, // IPMI::send/IPMI::sendrecv
- MOD_IPMISRV_REPLY = 0x02, // IPMI::respond
- MOD_IPMISENSOR = 0x03, // IPMI::sensor
- MOD_IPMIDCMI = 0x04, // IPMI::sensor
- MOD_IPMIRT = 0x05, // rt IPMI::send/IPMI::sendrecv
- MOD_IPMISRV_POSTEVENT = 0x06, // IpmiRP::postEvent
- MOD_IPMIFRU_INV = 0x07, // IPMI:fruInventory
+ MOD_IPMISRV_SEND = 0x01, // IPMI::send/IPMI::sendrecv
+ MOD_IPMISRV_REPLY = 0x02, // IPMI::respond
+ MOD_IPMISENSOR = 0x03, // IPMI::sensor
+ MOD_IPMIDCMI = 0x04, // IPMI::sensor
+ MOD_IPMIRT = 0x05, // rt IPMI::send/IPMI::sendrecv
+ MOD_IPMISRV_POSTEVENT = 0x06, // IpmiRP::postEvent
+ MOD_IPMIFRU_INV = 0x07, // IPMI:fruInventory
+ MOD_IPMISENSOR_TYPE = 0x08, // IPMI::getSensorType
+ MOD_IPMISENSOR_ENTITY_ID = 0x09, // IPMI::getSensorEntityId
+ MOD_IPMISENSOR_NAME = 0x0A, // IPMI::getSensorName
};
enum IPMIReasonCode
@@ -57,6 +60,7 @@ namespace IPMI
RC_GET_SENSOR_TYPE_CMD_FAILED = IPMI_COMP_ID | 0x0c,
RC_SENSOR_NOT_FOUND = IPMI_COMP_ID | 0x0d,
RC_INVALID_VPD_DATA = IPMI_COMP_ID | 0x0e,
+ RC_INVALID_SENSOR_NUMBER = IPMI_COMP_ID | 0x0f,
};
};
OpenPOWER on IntegriCloud